@@ -1,6 +1,6 @@
 package Test::Routine::Runner;
 # ABSTRACT: tools for running Test::Routine tests
-$Test::Routine::Runner::VERSION = '0.023';
+$Test::Routine::Runner::VERSION = '0.025';
 use Moose;
 
 #pod =head1 OVERVIEW
@@ -8,7 +8,7 @@ use Moose;
 #pod A Test::Routine::Runner takes a callback for building test instances, then uses
 #pod it to build instances and run the tests on it.  The Test::Routine::Runner
 #pod interface is still undergoing work, but the Test::Routine::Util exports for
-#pod running tests, descibed in L<Test::Routine|Test::Routine/Running Tests>, are
+#pod running tests, described in L<Test::Routine|Test::Routine/Running Tests>, are
 #pod more stable.  Please use those instead, unless you are willing to deal with
 #pod interface breakage.
 #pod
@@ -53,13 +53,6 @@ coerce 'Test::Routine::_InstanceBuilder',
   from 'Test::Routine::_Instance',
   via  { my $instance = $_; sub { $instance } };
 
-has test_instance => (
-  is   => 'ro',
-  does => 'Test::Routine::Common',
-  init_arg   => undef,
-  lazy_build => 1,
-);
-
 has _instance_builder => (
   is  => 'ro',
   isa => 'Test::Routine::_InstanceBuilder',
@@ -68,7 +61,7 @@ has _instance_builder => (
   init_arg => 'instance_from',
   required => 1,
   handles  => {
-    '_build_test_instance' => 'execute_method',
+    'build_test_instance' => 'execute_method',
   },
 );
 
@@ -78,19 +71,13 @@ has description => (
   required => 1,
 );
 
-has fresh_instance => (
-  is  => 'ro',
-  isa => 'Bool',
-  default => 0,
-);
-
 sub run {
   my ($self) = @_;
 
-  my $thing = $self->test_instance;
+  my $test_instance = $self->build_test_instance;
 
   my @tests = grep { Moose::Util::does_role($_, 'Test::Routine::Test::Role') }
-              $thing->meta->get_all_methods;
+              $test_instance->meta->get_all_methods;
 
   my $re = $ENV{TEST_METHOD};
   if (defined $re and length $re) {
@@ -109,8 +96,7 @@ sub run {
 
   Test2::API::run_subtest($self->description, sub {
     for my $test (@ordered_tests) {
-      $self->test_instance->run_test( $test );
-      $self->clear_test_instance if $self->fresh_instance;
+      $test_instance->run_test( $test );
     }
   });
 }
@@ -129,14 +115,14 @@ Test::Routine::Runner - tools for running Test::Routine tests
 
 =head1 VERSION
 
-version 0.023
+version 0.025
 
 =head1 OVERVIEW
 
 A Test::Routine::Runner takes a callback for building test instances, then uses
 it to build instances and run the tests on it.  The Test::Routine::Runner
 interface is still undergoing work, but the Test::Routine::Util exports for
-running tests, descibed in L<Test::Routine|Test::Routine/Running Tests>, are
+running tests, described in L<Test::Routine|Test::Routine/Running Tests>, are
 more stable.  Please use those instead, unless you are willing to deal with
 interface breakage.
 
